# Toga Layout Builder

The aim of this project is to create user interfaces easily with a yaml document. 
This is an unofficial tool for Toga GUI Toolkit.

## How to use

Look at https://github.com/ignaciocabeza/toga-layout-builder/tree/master/example to learn how to use it.